@@ -1,32 +1,29 @@
-use crate::config::{Config, Delimiter};
-use crate::util;
-use crate::CliResult;
-use serde::Deserialize;
-
-static USAGE: &str = "
+static USAGE: &str = r#"
 Drop a CSV file's header.
 
 Usage:
     qsv behead [options] [<input>]
+    qsv behead --help
 
 Common options:
     -h, --help             Display this message
     -o, --output <file>    Write output to <file> instead of stdout.
-    -d, --delimiter <arg>  The field delimiter for reading CSV data.
-                           Must be a single character. (default: ,)
-";
+"#;
+
+use serde::Deserialize;
+
+use crate::{config::Config, util, CliResult};
 
 #[derive(Deserialize)]
 struct Args {
-    arg_input: Option<String>,
-    flag_delimiter: Option<Delimiter>,
+    arg_input:   Option<String>,
     flag_output: Option<String>,
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
     let conf = Config::new(&args.arg_input)
-        .delimiter(args.flag_delimiter)
+        .checkutf8(false)
         .no_headers(false);
 
     let mut rdr = conf.reader()?;
