@@ -18,7 +18,7 @@ Usage:
     qsv dedup [options] [<input>]
     qsv dedup --help
 
-sort options:
+dedup options:
     -s, --select <arg>         Select a subset of columns to dedup.
                                Note that the outputs will remain at the full width
                                of the CSV.
@@ -45,6 +45,7 @@ Common options:
                                appear as the header row in the output.
     -d, --delimiter <arg>      The field delimiter for reading CSV data.
                                Must be a single character. (default: ,)
+    -Q, --quiet                Do not print duplicate count to stderr.
 "#;
 
 use std::cmp;
@@ -71,6 +72,7 @@ struct Args {
     flag_delimiter:      Option<Delimiter>,
     flag_human_readable: bool,
     flag_jobs:           Option<usize>,
+    flag_quiet:          bool,
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
@@ -132,6 +134,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             }
         }
     } else {
+        // we're loading the entire file into memory, we need to check avail mem
+        if let Some(path) = rconfig.path.clone() {
+            util::mem_file_check(&path)?;
+        }
+
         util::njobs(args.flag_jobs);
 
         let mut all = rdr.byte_records().collect::<Result<Vec<_>, _>>()?;
@@ -168,6 +175,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     }
 
     dupewtr.flush()?;
+    wtr.flush()?;
+
+    if args.flag_quiet {
+        return Ok(());
+    }
 
     if args.flag_human_readable {
         use thousands::Separable;
@@ -177,7 +189,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         eprintln!("{dupe_count}");
     }
 
-    Ok(wtr.flush()?)
+    Ok(())
 }
 
 /// Try comparing `a` and `b` ignoring the case
