@@ -9,6 +9,8 @@ Note that this requires reading all of the CSV data into memory. If
 you need to sort a large file that may not fit into memory, use the
 extsort command instead.
 
+For examples, see https://github.com/jqnatividad/qsv/blob/master/tests/test_sort.rs.
+
 Usage:
     qsv sort [options] [<input>]
     qsv sort --help
@@ -79,6 +81,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         .checkutf8(false)
         .select(args.flag_select);
 
+    // we're loading the entire file into memory, we need to check avail mem
+    if let Some(path) = rconfig.path.clone() {
+        util::mem_file_check(&path)?;
+    }
+
     let mut rdr = rconfig.reader()?;
 
     let headers = rdr.byte_headers()?.clone();
