@@ -16,7 +16,7 @@ use crate::{
 };
 
 // rdr default is 8k in csv crate, we're doubling it
-const DEFAULT_RDR_BUFFER_CAPACITY: usize = 16 * (1 << 10);
+pub const DEFAULT_RDR_BUFFER_CAPACITY: usize = 16 * (1 << 10);
 // previous wtr default in xsv is 32k, we're doubling it
 pub const DEFAULT_WTR_BUFFER_CAPACITY: usize = 64 * (1 << 10);
 
@@ -30,7 +30,7 @@ const UTF8_ERROR_MSG: &str = "is not UTF-8 encoded. Use the input command to tra
 // file size at which we warn user that a large file has not been indexed
 const NO_INDEX_WARNING_FILESIZE: u64 = 100_000_000; // 100MB
 
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy)]
 pub struct Delimiter(pub u8);
 
 /// Delimiter represents values that can be passed from the command line that
@@ -71,9 +71,8 @@ impl<'de> Deserialize<'de> for Delimiter {
     }
 }
 
-#[derive(Debug)]
 pub struct Config {
-    path:              Option<PathBuf>, // None implies <stdin>
+    pub path:          Option<PathBuf>, // None implies <stdin>
     idx_path:          Option<PathBuf>,
     select_columns:    Option<SelectColumns>,
     delimiter:         u8,
@@ -264,6 +263,7 @@ impl Config {
         self
     }
 
+    #[inline]
     pub fn selection(&self, first_record: &csv::ByteRecord) -> Result<Selection, String> {
         match self.select_columns {
             None => fail!("Config has no 'SelectColumns'. Did you call Config::select?"),
@@ -421,6 +421,23 @@ impl Config {
                             fs::File::open(util::idx_path(p)).unwrap()
                         } else {
                             warn!("No index file found - {p:?}: {e}");
+
+                            let (_, data_fsize) = util::file_metadata(&p.metadata()?);
+
+                            // If the CSV file is larger than NO_INDEX_WARNING_FILESIZE,
+                            // log a warning that the user should consider creating an index file
+                            // for faster access.
+                            if data_fsize > NO_INDEX_WARNING_FILESIZE {
+                                use thousands::Separable;
+
+                                warn!(
+                                    "The {} MB CSV file is larger than the {} MB \
+                                     NO_INDEX_WARNING_FILESIZE threshold. Consider creating an \
+                                     index file for faster access.",
+                                    (data_fsize * 100).separate_with_commas(),
+                                    (NO_INDEX_WARNING_FILESIZE * 100).separate_with_commas()
+                                );
+                            }
                             return Ok(None);
                         }
                     }
@@ -434,7 +451,7 @@ impl Config {
         // modified, then return an error and demand the user regenerate the index.
         // Unless QSV_AUTOINDEX is set, in which case, we'll recreate the
         // stale index automatically
-        let (data_modified, data_fsize) = util::file_metadata(&csv_file.metadata()?);
+        let (data_modified, _) = util::file_metadata(&csv_file.metadata()?);
         let (idx_modified, _) = util::file_metadata(&idx_file.metadata()?);
         if data_modified > idx_modified {
             if self.autoindex {
@@ -447,18 +464,6 @@ impl Config {
                 ));
             }
         }
-        // If the CSV file is larger than NO_INDEX_WARNING_FILESIZE,
-        // log a warning that the user should consider creating an index file for faster access.
-        if data_fsize > NO_INDEX_WARNING_FILESIZE {
-            use thousands::Separable;
-
-            warn!(
-                "The {} MB CSV file is larger than the {} MB NO_INDEX_WARNING_FILESIZE threshold. \
-                 Consider creating an index file for faster access.",
-                (data_fsize * 100).separate_with_commas(),
-                (NO_INDEX_WARNING_FILESIZE * 100).separate_with_commas()
-            );
-        }
         let csv_rdr = self.from_reader(csv_file);
         Ok(Some((csv_rdr, idx_file)))
     }
