@@ -21,6 +21,7 @@ macro_rules! command_list {
     excel       Exports an Excel sheet to a CSV
     exclude     Excludes the records in one CSV from another
     explode     Explode rows based on some column separator
+    extdedup    Remove duplicates rows from an arbitrarily large text file
     extsort     Sort arbitrarily large text file
     fill        Fill empty values
     fixlengths  Makes all records have same length
@@ -63,6 +64,7 @@ mod clitypes;
 mod cmd;
 mod config;
 mod index;
+mod odhtcache;
 mod select;
 mod util;
 
@@ -182,6 +184,7 @@ enum Command {
     Excel,
     Exclude,
     Explode,
+    ExtDedup,
     ExtSort,
     Fill,
     FixLengths,
@@ -238,6 +241,7 @@ impl Command {
             Command::Excel => cmd::excel::run(argv),
             Command::Exclude => cmd::exclude::run(argv),
             Command::Explode => cmd::explode::run(argv),
+            Command::ExtDedup => cmd::extdedup::run(argv),
             Command::ExtSort => cmd::extsort::run(argv),
             Command::Fill => cmd::fill::run(argv),
             Command::FixLengths => cmd::fixlengths::run(argv),
