@@ -50,6 +50,7 @@ mod test_excel;
 mod test_exclude;
 #[cfg(any(feature = "full", feature = "lite"))]
 mod test_explode;
+mod test_extdedup;
 #[cfg(any(feature = "full", feature = "lite"))]
 mod test_extsort;
 #[cfg(feature = "fetch")]
@@ -93,6 +94,7 @@ mod test_select;
 mod test_slice;
 mod test_sniff;
 mod test_sort;
+mod test_sortcheck;
 #[cfg(any(feature = "full", feature = "lite"))]
 mod test_split;
 mod test_stats;
